class Address
  include Mongoid::Document
  include Mongoid::History::Trackable

  embedded_in :department
  embedded_in :event
  embedded_in :organization

  field :line1, type: String
  field :street, type: String
  field :city, type: String
  field :state, type: String
  field :zip, type: String

  validate :address_if_off_campus

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [:department, :event, :organization]

  def address_if_off_campus
    if self.event.present? && self.event.location_type == 'off-campus'
      validates_presence_of :line1, :street, :city, :state, :zip
    end
  end

  def to_s
    line1
  end
  alias :title :to_s
end
