class AudienceCollection
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  # The following fields can be propogated on the fly from other sources in the db
  #  and all fields should be multiselectable. Perhaps we could provide a "select all"
  #  option as well.
  field :affiliations, type: Array # Student / Employee
  field :schools, type: Array # Rosemead, Talbot, Cook, etc.
  field :student_levels, type: Array # Undergrad / Grad / Online
  field :class_standings, type: Array # Freshman / Sophmore / Junior / Senior
  field :majors, type: Array
  field :housing_statuses, type: Array # On-campus / Appartments / Off-Campus Commuter
  field :employee_types, type: Array # Staff / Faculty
  field :departments, type: Array

  embedded_in :page_edition

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :page_edition ]

  def self.available_affiliations
    Person.distinct(:affiliations).compact.map(&:capitalize).sort
  end

  def self.available_schools
    School.asc(:title)
  end

  def self.available_student_levels
    Person.distinct(:level).sort
  end

  def self.available_class_standings
    ['Freshman', 'Sophmore', 'Junior', 'Senior']
  end

  def self.available_majors
    AcademicProgram.asc(:full_name)
  end

  def self.available_housing_statuses
    ['On-Campus', 'Apartments', 'Off-Campus Commuter'].sort
  end

  def self.available_employee_types
    ['Employee', 'Faculty']
  end

  def self.available_departments
    Department.asc(:title)
  end

end
