class BioEdition < Edition
  include Mongoid::History::Trackable

  ATTACHMENT_TYPES = %w(cv)
  ATTACHMENT_METADATA_FIELDS = [
    FormFieldDefinition.new(name: "type", label: "Type", type: "text_field", help_text: ATTACHMENT_TYPES.join(", ")),
  ]

  # TODO: what do we do with attachments when a new version is created?
  has_one :attachment, as: :attachable, dependent: :destroy
  belongs_to :person
  has_and_belongs_to_many :books
  embeds_many :expertise
  embeds_many :gallery_photos, as: :exhibitable

  field :biography, type: String # wysiwyg
  field :degrees, type: Array
  field :awards, type: String # wysiwyg
  field :professional_affiliations, type: String # wysiwyg
  field :publications, type: String # wysiwyg
  field :presentations, type: String # wysiwyg
  field :research_interests, type: Array
  field :courses, type: String # wysiwyg
  field :filmography, type: String # wysiwyg
  field :media_interviews, type: String #wysiwyg
  field :personal_website, type: String #wysiwyg

  index({title: 'text'}, {weights: {title: 10}, name: 'title_index'})

  validates :person_id, presence: true
  validates_uniqueness_of :slug, scope: :class
  validates :personal_website, absolute_uri: true, allow_blank: true

  # TODO: Add metadata to manage relationship to 'schools'

  before_validation :set_edition_fields

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  delegate(*%i[first_name middle_name last_name email social_media biola_title titles faculty_status], to: :person)

  alias :affiliations :professional_affiliations

  def cv
    attachment if attachment.present? && attachment.metadata[:type] == 'cv'
  end

  def cv_url
    cv.try(:attachment).try(:url)
  end

  private

  # Edition requires a title and slug so set it from the person
  def set_edition_fields
    unless person.nil?
      self.title ||= person.name
      set_slug
    end
  end

  def set_slug
    if self.person.slug.present?
      self.slug = self.person.slug
    elsif title?
      self.slug = title.parameterize
    end
  end
end
