class Book
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  has_and_belongs_to_many :bio_editions

  field :isbn, type: String
  field :title, type: String
  field :description, type: String
  field :publish_date, type: Date
  field :authors, type: Array
  field :image_url, type: String
  field :purchase_url, type: String

  before_validation :convert_to_isbn13

  # Some books had to be imported without ISBNs so we'll only validate ISBN on create.
  validates :isbn, presence: true, on: :create
  validates :isbn, isbn: true, uniqueness: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  def self.isbn_find(isbn)
    Book.where(isbn: isbn13(isbn)).first
  end

  def self.isbn13(isbn)
    Lisbn.new(isbn.to_s).isbn13
  end

  private

  def convert_to_isbn13
    self.isbn = Book.isbn13(self.isbn)
  end
end
