class Calendar
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include PermissionsSubject
  include ActsAsWebPage

  field :title, type: String
  field :start_date, type: Date
  field :end_date, type: Date
  field :tags, type: Array, default: []

  embeds_many :calendar_sections
  has_and_belongs_to_many :important_dates

  validates :title, presence: true
  validates :start_date, presence: true
  validates :end_date, presence: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  def to_s
    title
  end

  def date_string(format=:default, separator='-')
    case format
    when :long
      start_date.cwyear.to_s + separator + end_date.cwyear.to_s
    else
      start_date.cwyear.to_s + separator + end_date.cwyear.to_s[-2,2]
    end
  end

  scope :by_tag, -> tag { where(tags: tag) }
  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({title: q},{tags: q})
      end
    rescue ::RegexpError
      Calendar.none
    end
  }
end
