class CalendarSection
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  field :title, type: String
  field :start_date, type: Date
  field :end_date, type: Date

  embedded_in :calendar

  validates :title, presence: true, uniqueness: true
  validates :start_date, presence: true, uniqueness: true

  track_history on: :fields, track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :calendar ]

  def to_s
    title
  end

  def important_dates
    # Only show dates that start during the section
    calendar.important_dates.where({
      :start_date.gte => start_date,
      :start_date.lte => end_date,
    })
  end

end
