class CampusLocation
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  MAIN_CAMPUS = { street: "13800 Biola Ave", city: "La Mirada", state: "California", zip: "90639" }

  field :name, type: String # e.g. Archery Range
  field :external_id, type: Integer # From 25live (e.g. 198)
  field :description, type: String # e.g. By the tennis courts
  field :latitude, type: Float
  field :longitude, type: Float

  validates_presence_of :external_id, :name
  validates_uniqueness_of :external_id, :name

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({name: q},{description: q})
      end
    rescue ::RegexpError
      CampusLocation.none
    end
  }

  def title
    name
  end
  alias :to_s :title
end
