class CatalogEntry
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  embedded_in :cataloged, polymorphic: true

  field :external_id, type: Integer
  field :external_catalog_id, type: Integer
  field :raw_data, type: Hash

  track_history on: :fields, track_create: true,
                track_update: true,
                track_destroy: true,
                scope: :cataloged

  # raw_data fields for a course
  # Catalog OID => 18
  # Catalog Name => 2014–15 Catalog
  # Course School/College Code => nil/blank
  # Course School/College Name => nil/blank
  # Course Department Code => nil/blank
  # Course Department Name => nil/blank
  # Entity Type => T
  # Entity OID => 1107
  # Entity Name => Chemistry - Undergraduate
  # Course OID => 29585
  # Course Type => Chemistry (CHEM)
  # Prefix => CHEM
  # Code => 302
  # Name => Organic Chemistry II
  # Description => <p>Continuation of Organic Chemistry I. Continued work with more complicated reactions and mechanisms. An introduction to computer-based drawing and searching tools. The last third of the course is devoted to the structure and properties of major biochemical substances.</p>
  # Description (Rendered) => <p>Continuation of Organic Chemistry I. Continued work with more complicated reactions and mechanisms. An introduction to computer-based drawing and searching tools. The last third of the course is devoted to the structure and properties of major biochemical substances.</p>
  # Description (Rendered no HTML) => Continuation of Organic Chemistry I. Continued work with more complicated reactions and mechanisms. An introduction to computer-based drawing and searching tools. The last third of the course is devoted to the structure and properties of major biochemical substances.
  # When Offered => <often blank, but string can vary>
  # Lecture/Lab Hours => <often blank, but string can vary>
  # Cross-listed => <often blank, but string can vary>
  # Prerequisite(s) => CHEM 301.
  # Corequisite(s) => <often blank, but string can vary>
  # Restriction(s) => <often blank, but string can vary>
  # Note(s) => <often blank, but string can vary>
  # Fee => <often blank, but string can vary>
  # Grade Mode => A.
  # Credit(s) => 3
  # Is Active => 1
  # Creation Date => 7/26/2013 19:41:05
  # Last Modified => 2/25/2014 16:39:21

end
