# NOTE: Concentration routes need to be embedded within their particular Academic program
#  because slugs are only uniq within their associated program.

class Concentration
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include HasPages

  belongs_to :academic_program
  has_many :degree_requirements
  # It would be nice to reference the requirement sections from here, but we can't
  #   because they are embedded under an academic program. Grr...
  # has_many :requirement_sections

  before_validation :set_slug

  field :title, type: String
  field :slug, type: String
  field :description, type: String
  field :curriculum, type: Array

  validates_presence_of :title
  validates_presence_of :slug
  validates_uniqueness_of :slug, scope: :academic_program, allow_blank: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  def to_s
    title
  end

  private
  def set_slug
    if title? && !slug?
      self.slug = title.parameterize
    elsif slug?
      self.slug = slug.parameterize
    end
  end
end
