module ActsAsWebPage
  extend ActiveSupport::Concern
  include StringAccessorForArray

  included do
    field :page_title, type: String # to be used as the <title> tag field in the <head>
    field :meta_description, type: String
    field :meta_robots, type: String
    field :meta_keywords, type: Array
    field :canonical_url, type: String
    field :end_of_head_html, type: String
    field :end_of_body_html, type: String

    string_accessor_for_array :meta_keywords

    META_ROBOTS_OPTIONS ||= %w(noindex nofollow nosnippet noodp noarchive unavailable_after noimageindex)
    # Meta Robots Options
    # noindex: prevents the page from being indexed
    # nofollow: prevents the Googlebot from following links from this page
    # nosnippet: prevents a snippet from being shown in the search results
    # noodp: prevents the alternative description from the ODP/DMOZ from being used
    # noarchive: prevents Google from showing the Cached link for a page.
    # unavailable_after:[date]: lets you specify the exact time and date you want to stop crawling and indexing of this page
    # noimageindex: lets you specify that you do not want your page to appear as the referring page for an image that appears in Google search results.

    validates :meta_robots, inclusion: { in: META_ROBOTS_OPTIONS, allow_blank: true }
    validates :canonical_url, absolute_uri: true, allow_blank: true

    def meta_fields
      {
        title: (page_title.presence || try(:title)),
        description: meta_description,
        robots: meta_robots,
        keywords: meta_keywords,
        canonical_url: canonical_url
      }
    end
  end
end

