module Employee
  extend ActiveSupport::Concern

  included do
    field :department, type: String # not user changeable
    field :biola_title, type: String # not user changeable
    field :friendly_biola_title, type: String
    field :additional_titles, type: Array
    field :office_location, type: String
    field :job_description, type: String
    field :employee_phone, type: String # not user changeable
    field :alternate_employee_phone, type: String
    field :work_email, type: String
    field :show_employee_phone, type: Boolean
    field :show_work_email, type: Boolean

    # This can be done away with if we would rather check for whether the work email is set or not
    field :use_work_email, type: Boolean, default: false

    has_and_belongs_to_many :assistants, class_name: "Person"

  end

  def titles
    # .presence will turn empty strings into nil.
    [friendly_biola_title.presence || biola_title.presence].compact + additional_titles.to_a
  end

  def best_biola_title
    friendly_biola_title.presence || biola_title
  end

  def preferred_biola_email
    (use_work_email? && work_email.present?) ? work_email : biola_email
  end

  def additional_titles_string
    self.additional_titles.join('| ') if additional_titles.present?
  end

  def assistant_to
    Person.where(assistant_ids: self.id)
  end

  def add_assistant!(new_assistant)
    self.assistants << new_assistant
    self.save
  end

  # TODO: Adam wants this changed to be in the controllers
  def additional_titles_string=(string)
    self.additional_titles = string.to_s.split('|').map(&:strip)
  end

  def department_title
    departments.first.try(:title) || department
  end
end
