module HasPages
  extend ActiveSupport::Concern

  included do
    field :primary_page_id, type: String # main page for parent object
    field :page_url, type: String # should be the full page url

    has_many :page_editions, as: :source

    validates :page_url, absolute_uri: true, allow_blank: true

    scope :with_primary_page, -> { where(:page_url.ne => nil) }

    def primary_page
      page_editions.where(id: primary_page_id).first
    end

    def primary_page=(page)
      if page && page.is_a?(PageEdition)
        write_attribute :primary_page_id, page.id.to_s
        self.page_url = page.url if page.published?
        self.page_editions << page unless self.page_editions.include?(page)
      else
        write_attribute :primary_page_id, nil
        self.page_url = nil
      end
    end

    def primary_page_id=(page_id)
      self.primary_page = page_id.present? ? PageEdition.find(page_id) : nil
    end

    def page_url=(string)
      # Save empty string as nil
      write_attribute :page_url, string.presence
    end
  end
end
