class CustomProfile
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include WorkFlow
  include RelatesObjectTags
  include HasPresentationData
  include ActsAsWebPage

  belongs_to :person
  belongs_to :profile_photo

  embeds_many :gallery_photos, as: :exhibitable

  field :slug, type: String
  field :body, type: String
  field :type, type: String

  validates_presence_of :type, :person_id
  validates_uniqueness_of :slug, scope: :type, allow_blank: true
  validates_uniqueness_of :type, scope: :person

  before_validation :set_slug
  validate :slug_available

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  def to_s
    type
  end

  private
  def set_slug
    self.slug ||= person.slug
  end

  def slug_available
    unless slug.present? || person.slug.present?
      errors.add(:slug, "cannot be automatically generated. Please add a slug to the person's bio first.")
    end
  end
end
