class DegreeRequirement
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  before_validation :set_academic_program, :set_level

  belongs_to :catalog
  belongs_to :academic_program
  belongs_to :concentration
  has_many :attachments, as: :attachable, dependent: :destroy

  CATEGORY = ['torrey', 'degree-completion']

  ATTACHMENT_METADATA_FIELDS = [
    FormFieldDefinition.new(name: "category", label: "Category", type: "text_field", help_text: CATEGORY.join(", ")),
  ]

  field :code, type: String
  field :level, type: String    # Grad/Undergrad/Undergrad Degree Completion
  field :grouping, type: String # Major e.g. Physics, Biological Sciences

  validates_presence_of :academic_program, :catalog, :code
  validates_uniqueness_of :academic_program, scope: [:catalog, :code]

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  def set_academic_program
    self.academic_program = concentration.academic_program if concentration? && !academic_program?
  end

  def set_level
    (academic_program.level == :bachelor) ? self.level = :undergraduate : self.level = :graduate
  end

  def to_s
    code
  end
end
