class Document
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  embedded_in :documentable, polymorphic: true

  before_create :set_order

  field :title, type: String
  field :order, type: Integer
  field :url, type: String

  mount_uploader :document, DocumentUploader

  validates_presence_of :title
  validate :url_xor_document

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: :documentable

  def to_s
    title
  end

  private

  def set_order
    self.order ||= (documentable.documents.count + 1) if documentable?
  end

  def url_xor_document
    if !(url.blank? ^ document.blank?)
      errors.add(:base, "Specify either Url or document to be uploaded, not both.")
    end
  end
end
