class EventCollection
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include HasPages

  field :title, type: String
  field :slug, type: String

  has_and_belongs_to_many :events

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  validates_presence_of :title, :slug
  validates :slug, format: { with: /\A[a-z\d_\-\/]*\Z/ }

  def to_s
    title
  end

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({title: q})
      end
    rescue ::RegexpError
      EventCollection.none
    end
  }
end
