class Expertise
  include Mongoid::Document
  include Mongoid::History::Trackable

  embedded_in :bio_edition
  field :topic, type: String
  field :slug, type: String

  validates :topic, :slug, presence: true, uniqueness: true

  before_validation :set_slug, unless: :slug?

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :bio_edition ]

  def to_s
    topic.to_s
  end

  # sets slug from title
  def set_slug
    self.slug = topic.parameterize if topic?
  end
end
