class ExternalArticle < Edition
  include Mongoid::Document
  include Mongoid::History::Trackable
  include Thumbnail
  include RelatesObjectTags

  field :body, type: String
  field :source_author, type: String
  field :categories, type: Array
  field :guid, type: String

  belongs_to :author, class_name: "Person", inverse_of: :external_articles
  belongs_to :external_blog

  validates_presence_of :title, :body, :external_blog, :guid
  validates_uniqueness_of :slug, scope: :class
  validate :author_or_source_author

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({title: q}, {url: q})
      end
    rescue ::RegexpError
      ExternalArticle.none
    end
  }

  def to_s
    title
  end

  private
  def author_or_source_author
    unless source_author.present? || author.present?
      errors.add :base, 'Must have an author or a external_blog author from external site.'
    end
  end

  # sets slug from title
  def set_slug
    if title?
      appendage = nil
      while ::ExternalArticle.where(slug: "#{title.parameterize}#{appendage}").present?
        appendage.nil? ? appendage = 1 : appendage += 1
      end
      self.slug = "#{title.parameterize}#{appendage}"
    end
  end
end
