require 'uri'

class ExternalBlog
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include Thumbnail
  include PermissionsSubject
  include WorkFlow

  has_many :external_articles

  field :title, type: String
  field :feed_url, type: String
  field :url, type: String
  field :to_sync, type: Boolean, default: false

  validates_presence_of :title, :feed_url, :url
  validates :feed_url, absolute_uri: true
  validates :url, absolute_uri: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({title: q})
      end
    rescue RegexpError
      ExternalBlog.none
    end
  }

  def to_s
    title
  end
end
