class GalleryPhoto
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  embedded_in :exhibitable, polymorphic: true

  field :caption, type: String
  field :order, type: Integer

  validates_uniqueness_of :order
  validates_presence_of :photo, :order

  mount_uploader :photo, GalleryPhotoUploader

  scope :ordered, -> { asc(:order) }

  before_validation :set_order

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: :exhibitable

  private
  def set_order
    self.order = exhibitable.gallery_photos.distinct(:order).compact.max.to_i + 1
  end
end
