class LearningOutcome
  include Mongoid::Document
  include Mongoid::History::Trackable

  embedded_in :academic_program

  field :text, type: String
  field :ulo_codes, type: Array # should contain list of University Learning Outcome slugs
  field :position, type: Integer

  validates :text, presence: true
  validates :position, presence: true, uniqueness: true

  before_validation :increment_position, unless: :position?

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :academic_program ]

  scope :in_order, -> { asc(:position) }

  def ulos
    # TODO look up ulos with the ulo_codes
  end

  def ulo_codes_list=(arg)
    self.ulo_codes = arg.split(',').map { |v| v.strip }
  end

  def ulo_codes_list
    self.ulo_codes.join(', ') unless self.ulo_codes.nil?
  end

  private

  def increment_position
    self.position = self._parent.learning_outcomes.where(:position.ne => nil).in_order.last.try(:position).to_i + 1
  end
end
