class Medium
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include RelatesObjectTags

  field :title, type: String
  field :subtitle, type: String
  mount_uploader :thumbnail, ThumbnailUploader
  mount_uploader :video_placeholder_image, ThumbnailUploader

  embeds_many :media_resources

  validates_presence_of :title
  validates_uniqueness_of :title

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({title: q})
      end
    rescue ::RegexpError
      Medium.none
    end
  }
end
