class Organization
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  field :title, type: String
  field :website, type: String
  field :phone, type: String
  field :email, type: String

  embeds_one :address
  embeds_many :social_media
  has_and_belongs_to_many :sponsored_events, class_name: 'Event', inverse_of: :external_sponsors

  mount_uploader :logo, GenericPhotoUploader

  validates :title, presence: true, uniqueness: true
  validates :website, absolute_uri: true, allow_blank: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({title: q})
      end
    rescue ::RegexpError
      Organization.none
    end
  }

  def to_s
    title
  end

end
