# a special edition used only for the outcomes front end website
class OutcomeEdition < Edition
  include Mongoid::History::Trackable

  has_many :attachments, as: :attachable
  embeds_many :parts

  ATTACHMENT_METADATA_FIELDS = []

  field :introduction, type: String
  field :body, type: String

  validates_uniqueness_of :slug, scope: :class

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({ title: q })
      end
    rescue ::RegexpError
      OutcomeEdition.none
    end
  }

  def whole_body
    [introduction, body, parts.map(&:body)].flatten.join("\n\n")
  end
end
