class Part
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  embedded_in :outcome_edition, inverse_of: :parts

  field :position, type: Integer
  field :title, type: String
  field :body, type: String
  field :slug, type: String
  field :description, type: String

  alias :to_s :title

  validates :title, presence: true, uniqueness: true
  validates :slug, presence: true, uniqueness: true
  validates :position, presence: true, uniqueness: true
  validates_format_of :slug, with: /\A[a-z0-9\-]+\Z/i

  before_validation :set_slug, unless: :slug?
  before_validation :increment_position, unless: :position?

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :outcome_edition ]

  scope :in_order, -> { asc(:position) }

  private

  # sets slug from title
  def set_slug
    self.slug = title.parameterize if title?
  end

  def increment_position
    self.position = self._parent.parts.where(:position.ne => nil).in_order.last.try(:position).to_i + 1
  end
end
