##
# Gives users access to manage specific data.
class Permission
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  # This should should have been polymorphic
  # embedded_in :permissible, polymorhic: true
  embedded_in :department
  embedded_in :event
  embedded_in :external_blog
  embedded_in :feature
  embedded_in :group
  embedded_in :page_edition
  embedded_in :person
  embedded_in :site
  embedded_in :site_category

  # belongs_to :actor, polymorphic: true
  field :actor_id, type: String
  field :actor_type, type: String
  field :ability, type: Symbol

  validates_presence_of :actor_id, :actor_type, :ability
  validates_uniqueness_of :actor_id, scope: %i[actor_type ability]

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: %i[department event external_blog feature group
                          page_edition person site site_category]

  scope :by_actor, (lambda do |actor|
    where(actor_type: actor.class.to_s, actor_id: actor.id.to_s)
  end)

  def actor
    actor_type.constantize.find(actor_id) unless actor_type.blank?
  end
end
