class PhotoGallery
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include RelatesObjectTags

  embeds_many :gallery_photos, as: :exhibitable

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  field :title, type: String
  field :slug, type: String

  validates_presence_of :title, :slug
  validates_uniqueness_of :title, :slug

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({title: q})
      end
    rescue ::RegexpError
      PhotoGallery.none
    end
  }
end
