class PresentationDataTemplate
  include Mongoid::Document
  include Mongoid::History::Trackable
  include HasJsonSchema

  field :title, type: String
  field :target_class, type: String

  # Depricate :schema. After releasing this I will migrate everything that is in the old
  # schema format and convert it to the json-schema standard and save it in :json_schema
  field :schema, type: Array, default: []

  # New json schema, this will replace schema.
  # Should match json-schema standard - http://json-schema.org/
  field :json_schema, type: String
  create_json_schema_validations :json_schema
  validate :validate_json_schema # this method is defined in HasJsonSchema

  validates :title, uniqueness: true, presence: true
  validates :target_class, presence: true

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, ::Regexp::IGNORECASE)
        any_of({title: q}, {target_class: q})
      end
    rescue ::RegexpError
      PresentationDataTemplate.none
    end
  }

  alias :to_s :title

  # Depricated. TODO: Remove when you remove :schema
  def schema_json
    JSON.pretty_generate(schema)
  end

  # Depricated. TODO: Remove when you remove :schema
  def schema_json=(json)
    begin
      self.schema = JSON.parse(json)
    rescue JSON::ParserError
      return false
    end
  end

end
