class ProfilePhoto
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  belongs_to :person
  belongs_to :organization
  field :description, type: String
  field :type, type: String

  mount_uploader :photo, ProfilePhotoUploader

  validates :photo, presence: true

  after_destroy :clear_person_profile_photo_if_primary

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({type: q})
      end
    rescue ::RegexpError
      ProfilePhoto.none
    end
  }

  def primary?
    person.profile_photo == self
  end

  def make_primary
    person.update_attribute(:profile_photo_id, self.id)
  end

  def clear_person_profile_photo_if_primary
    person.update_attribute(:profile_photo_id, nil) if self.primary?
  end
end
