class Publication < Edition
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  field :initial_publication, type: Date # optional
  field :last_updated, type: Date
  field :detail, type: String # To be a WYSIWYG
  field :type, type: String # examples: "transparency data", "syllabus", "guidance", "correspondence", "position paper", "proposals", "research and analysis"
  field :audiences, type: Array

  embeds_many :documents, as: :documentable
  has_and_belongs_to_many :publication_categories
  has_and_belongs_to_many :groups
  has_and_belongs_to_many :departments

  validates_presence_of :title, :slug, :type
  validates_uniqueness_of :slug, scope: :class

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :by_type, -> type { where(types: type) }
  scope :by_audience, -> audiences { where(audiences: audiences) }

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({title: q})
      end
    rescue ::RegexpError
      Publication.none
    end
  }

  alias :to_s :title
end
