class PublicationCategory
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  # include PermissionsSubject
  CATEGORIES = ['']

  has_and_belongs_to_many :publications

  field :title, type: String
  field :slug, type: String
  field :description, type: String
  field :body, type: String
  field :template, type: String

  before_validation :set_slug, unless: :slug?

  validates_uniqueness_of :slug, :title
  validates_format_of :slug, with: /\A[\w\-]+\Z/i
  validates_presence_of :title, :slug, :description, :body

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({title: q})
      end
    rescue RegexpError
      PublicationCategory.none
    end
  }

  alias :to_s :title

  protected
  def set_slug
    self.slug = title.parameterize if title?
  end

end
