class Redirect
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  TYPES = [ 'Temporary', 'Permanent' ]
  STRING_HANDLING_OPTIONS = [ 'Drop', 'Pass Along' ]

  embedded_in :page_edition

  # destination can either be a local (/local/url) or remote (http://remote.url) url
  field :destination, type: String
  field :type, type: String, default: 'Permanent'
  field :query_string_handling, type: String

  validates :type, inclusion: { in: TYPES, allow_blank: true }
  validates :query_string_handling, inclusion: { in: STRING_HANDLING_OPTIONS, allow_blank: true }
  validate :destination_formatting

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :page_edition ]

  private
  def destination_formatting
    if destination.present?
      unless (uri?(destination) || valid_relative_url?(destination))
        errors.add :base, 'The destination either needs to be a full url or a valid relative url.'
      end
    end
  end

  def uri?(string)
    uri = URI.parse(string)
    %w( http https ).include?(uri.scheme)
  rescue URI::BadURIError
    false
  rescue URI::InvalidURIError
    false
  end

  def valid_relative_url?(string)
    string.starts_with?('/')
  end

end
