class RequirementSection
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable
  include StringAccessorForArray

  # should always be embedded in an academic program
  embedded_in :academic_program
  # optionally belongs to one concentration,
  #   if so, the concentration should also belong to the same academic program
  belongs_to :concentration
  # optionally contains courses
  has_and_belongs_to_many :courses

  field :title, type: String
  field :description, type: String

  validates :academic_program, presence: true
  validates :title, presence: true
  validate :concentration_in_same_academic_program

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :academic_program ]

  def courses_string(separator=",")
    courses.map(&:course_key).join(separator)
  end

  # If you want to specify the separator...
  #   related_object_tags_string = "some string", " | "
  def courses_string=(args)
    string, separator = get_string_and_separator(args)
    course_keys = String(string).split(separator).map(&:strip)
    self.courses = Course.by_keys(course_keys)
  end

  private

  def concentration_in_same_academic_program
    if concentration? && concentration.academic_program != academic_program
      errors.add :concentration, 'must be in the same academic program'
    end
  end
end
