# School: Defines all of Biola's active Schools
class School
  include Mongoid::Document
  include Mongoid::History::Trackable
  include RelatesObjectTags
  include HasPresentationData

  has_many :academic_programs
  has_and_belongs_to_many :academic_subjects

  field :title, type: String
  field :slug, type: String

  validates :title, :slug, uniqueness: true, presence: true

  track_history on: :fields, track_create: true,
                track_update: true, track_destroy: true

  scope :custom_search, (lambda do |query|
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of(title: q)
      end
    rescue ::RegexpError
      School.none
    end
  end)

  alias to_s title
end
