class SocialMedium
  include Mongoid::Document
  include Mongoid::History::Trackable



  embedded_in :person
  embedded_in :department
  embedded_in :organization

  ACCOUNT_TYPES = [:twitter, :facebook, :linkedin, :google, :instagram, :pinterest, :youtube, :vimeo]

  field :account, type: String
  field :url, type: String
  field :type, type: Symbol

  validates :url, :type, :account, presence: true
  validates :url, absolute_uri: true
  validates :type, inclusion: { in: ACCOUNT_TYPES }

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [:person, :department, :organization]

  def set_attrs_from(url)
    split_url = SocialMediaUrlSplitter.new(url)

    self.url = url
    self.type = split_url.type
    self.account = split_url.account
  end
end
