require 'uri'

class Ticket
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::History::Trackable

  embedded_in :event

  field :description, type: String
  field :cost, type: Float
  field :fine_print, type: String
  field :link, type: String

  validates :description, presence: true
  validates :link, absolute_uri: true, allow_blank: true
  validates_numericality_of :cost, only_float: true, greater_than_or_equal_to: 0, message: 'must be a positive integer'

  track_history on: :fields,
                track_create: true,
                track_update: true,
                track_destroy: true,
                scope: [ :event ]
end
