class UniversityLearningOutcome
  include Mongoid::Document
  include Mongoid::History::Trackable

  field :number, type: Integer
  field :name, type: String
  field :text, type: String
  field :code, type: String

  validates :code, uniqueness: true
  validates :number, presence: true, uniqueness: true
  validates :name, presence: true, uniqueness: true
  validates :text, presence: true

  before_validation :set_code

  track_history on: :fields, track_create: true, track_update: true, track_destroy: true

  scope :custom_search, -> query {
    begin
      if query.present?
        q = ::Regexp.new(query.to_s, 'i')
        any_of({ name: q })
      end
    rescue ::RegexpError
      UniversityLearningOutcome.none
    end
  }

  alias :to_s :name

  private

  def set_code
    self.code = "ulo-#{number}" unless self.number.nil?
  end
end
