require 'carrierwave/processing/mini_magick'

class ArticlePhotoUploader < CarrierWave::Uploader::Base
  include CarrierWave::MiniMagick
  include RozUploadable

  # Add a white list of extensions which are allowed to be uploaded.
  # For images you might use something like this:
  def extension_white_list
    %w(jpg jpeg png)
  end

  # Scale down original file if it is too big
  process :resize_to_limit => [2048, 2048]

  # 5 x 3
  version :x_small do
    process :crop
    process :resize_to_fill => [200, 120]
  end

  # 5 x 3
  version :small do
    process :crop
    process :resize_to_fill => [400, 240]
  end

  # 5 x 3
  version :medium do
    process :crop
    process :resize_to_fill => [600, 360]
  end

  # 5 x 3
  version :large do
    process :crop
    process :resize_to_fill => [800, 480]
  end

  # 5 x 2
  version :x_large do
    process :resize_to_fill => [1200, 480]
  end

  # 5 x 2
  version :xx_large do
    process :resize_to_fill => [1600, 640]
  end

  def crop
    if model.try(:crop_x).present?
      manipulate! do |img|
        x = model.crop_x.to_i
        y = model.crop_y.to_i
        w = model.crop_w.to_i
        h = model.crop_h.to_i
        img.crop("#{w}x#{h}+#{x}+#{y}")
        img
      end
    end
  end
end
