module BuwebContentModels
  require 'buweb_content_models/configuration'

  require 'mongoid'
  require 'mongoid-history'
  require 'mongoid_slug'
  require 'elasticsearch'
  require 'elasticsearch/model'

  require 'buweb_content_models/railtie' if defined?(Rails)
  require 'buweb_content_models/initializers/inflections'

  require 'active_support/concern'

  require 'active_model/validations'
  require 'email_validator'

  require 'carrierwave/mongoid'
  require 'carrierwave_roz'

  require 'wisper'

  FILES_TO_LOAD = [
    # Models
    'buweb/address',
    'buweb/academic_card',
    'buweb/academic_program_format',
    'buweb/academic_program_type',
    'buweb/academic_program',
    'buweb/academic_subject',
    'buweb/academic_topic',
    'buweb/activity_log',
    'buweb/attachment',
    'buweb/article',
    'buweb/audience_collection',
    'buweb/book',
    'buweb/calendar',
    'buweb/calendar_section',
    'buweb/campus_location',
    'buweb/catalog',
    'buweb/catalog_entry',
    'buweb/change',
    'buweb/course',
    'buweb/custom_profile',
    'buweb/concentration',
    'buweb/degree_requirement',
    'buweb/department',
    'buweb/department_contact',
    'buweb/document',
    'buweb/edition',
    'buweb/embedded_image',
    'buweb/emergency_status',
    'buweb/event',
    'buweb/event_collection',
    'buweb/event_occurrence',
    'buweb/expertise',
    'buweb/external_article',
    'buweb/external_blog',
    'buweb/feature',
    'buweb/feature_location',
    'buweb/gallery_photo',
    'buweb/generic_object',
    'buweb/group',
    'buweb/important_date',
    'buweb/learning_outcome',
    'buweb/link',
    'buweb/medium',
    'buweb/media_resource',
    'buweb/membership',
    'buweb/menu',
    'buweb/outcome_edition',
    'buweb/organization',
    'buweb/page_edition',
    'buweb/part',
    'buweb/permission',
    'buweb/person',
    'buweb/photo',
    'buweb/photo_gallery',
    'buweb/presentation_data_template',
    'buweb/publication',
    'buweb/publication_category',
    'buweb/redirect',
    'buweb/relationship',
    'buweb/requirement_section',
    'buweb/bio_edition',
    'buweb/profile_photo',
    'buweb/school',
    'buweb/service_link',
    'buweb/site',
    'buweb/site_category',
    'buweb/social_medium',
    'buweb/tag',
    'buweb/ticket',
    'buweb/university_learning_outcome',
    'buweb/user',

    # Concerns
    'buweb/concerns/acts_as_web_page',
    'buweb/concerns/alumnus',
    'buweb/concerns/article_photo',
    'buweb/concerns/biola_phone',
    'buweb/concerns/elasticsearchable',
    'buweb/concerns/employee',
    'buweb/concerns/has_json_schema',
    'buweb/concerns/has_pages',
    'buweb/concerns/has_presentation_data',
    'buweb/concerns/permissions_subject',
    'buweb/concerns/permissions_actor',
    'buweb/concerns/relates_object_tags',
    'buweb/concerns/roz_uploadable',
    'buweb/concerns/string_accessor_for_array',
    'buweb/concerns/student',
    'buweb/concerns/thumbnail',
    'buweb/concerns/trogdir_person',
    'buweb/concerns/work_flow',

    # Validators
    'buweb/validators/absolute_uri_validator',
    'buweb/validators/array_validator',
    'buweb/validators/course_keys_validator',
    'buweb/validators/isbn_validator',

    # Service Objects
    'buweb/services/form_field_definition',
    'buweb/services/social_media_url_splitter',

    # Uploaders
    'buweb/uploaders/article_photo_uploader',
    'buweb/uploaders/attachment_uploader',
    'buweb/uploaders/document_uploader',
    'buweb/uploaders/event_photo_uploader',
    'buweb/uploaders/gallery_photo_uploader',
    'buweb/uploaders/profile_photo_uploader',
    'buweb/uploaders/feature_photo_uploader',
    'buweb/uploaders/embedded_image_uploader',
    'buweb/uploaders/generic_photo_uploader',
    'buweb/uploaders/thumbnail_uploader'
  ]

  def self.root
    Pathname.new(File.dirname(__dir__))
  end

  # Bypass autoloading and force all classes to be loaded
  def self.force_load_all
    FILES_TO_LOAD.each { |file| require file }
  end

  # For sharing factories with apps that use the gem
  def self.load_factories
    FactoryGirl.definition_file_paths += [File.expand_path('../../spec/factories',  __FILE__)]
  end

  def self.configure
    yield config
  end
  def self.config
    @config ||= Configuration.new
  end
end

BuwebContentModels::FILES_TO_LOAD.each do |file|
  autoload file.camelcase.demodulize.to_sym, file
end

Mongoid::History.tracker_class_name = :change
