module BuwebContentModels
  class Configuration
    attr_accessor :elasticsearch_index
    attr_accessor :elasticsearch_settings
    attr_accessor :elasticsearch_mappings
    attr_accessor :elasticsearchable_models
    attr_accessor :urn_namespaces
    attr_accessor :roz_api_base_url
    attr_accessor :roz_files_base_url
    attr_accessor :roz_access_id
    attr_accessor :roz_secret_key

    def initialize
      @elasticsearch_index = 'buweb_test'  # this should get overwritten in your configuration file.
      @elasticsearch_settings = {
        analysis: {
          filter: {
            edge_ngram_filter: {
              type: "edgeNGram",
              min_gram: 2,
              max_gram: 35
            }
          },
          analyzer: {
            edge_ngram_analyzer: {
              tokenizer: 'lowercase',
              filter: ['edge_ngram_filter'],
              type: 'custom'
            }
          }
        }
      }
      @elasticsearch_mappings = {}
      @elasticsearchable_models = []
      @urn_namespaces = []
      @roz_api_base_url = 'https://api.biola.edu/assets/'
      @roz_files_base_url = 'https://assets.biola.edu/'
    end

    def elasticsearch_host=(_host)
      warn '[DEPRECATION] `elasticsearch_host=` is deprecated. It is no longer used for anything.'
    end

    def elasticsearch_host
      warn '[DEPRECATION] `elasticsearch_host` is deprecated. It is no longer used for anything.'
    end

    def elasticsearchable_models
      set_elasticsearchable_models unless @_models_have_been_set
      @elasticsearchable_models
    end

    def elasticsearch_mappings
      set_elasticsearch_mappings unless @_mappings_have_been_set
      @elasticsearch_mappings
    end

    private

    # Deprecated: this is no longer in use as we are defining the models manually
    def set_elasticsearchable_models
      # inspired by http://goo.gl/RJk2yK
      dir = File.expand_path('../../buweb',  __FILE__)
      Dir.glob(File.join("#{dir}/*.rb")).each do |path|
        model_filename = File.basename(path, ".rb") # Example: "academic_program"

        begin
          klass = Kernel.const_get model_filename.classify
        rescue NameError
          # Not sure this really needs to throw an error or if it should just keep going
          require(path) ? retry : raise(RuntimeError, "Cannot load class '#{klass}' from filename: '#{model_filename}'")
        end

        next unless klass.respond_to?(:__elasticsearch__)
        @elasticsearchable_models << klass
        @_models_have_been_set = true
      end
    end

    def set_elasticsearch_mappings
      elasticsearchable_models.each do |klass|
        @elasticsearch_mappings.merge! klass.mappings.to_hash
      end
      @_mappings_have_been_set = true
    end
  end
end
